"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = exports.LoggerSegmentsWrapper = void 0;
const Debugger = require("debug");
const utils_1 = require("../../utils");
class LoggerSegmentsWrapper {
    constructor(segments) {
        this.segments = new Map();
        this.segments = new Map(segments);
    }
    close() {
        for (const [key, segment] of this.segments) {
            segment.close();
        }
    }
    reportException(e, namespace = 'default') {
        for (const [key, segment] of this.segments) {
            segment.reportException(e, namespace);
        }
    }
    addContext(context = {}) {
        for (const [key, segment] of this.segments) {
            segment.addContext(context);
        }
    }
}
exports.LoggerSegmentsWrapper = LoggerSegmentsWrapper;
var Logger;
(function (Logger) {
    const loggers = new Map();
    Logger.addLogger = (key, logger) => {
        utils_1.Assert(!loggers.has(key), utils_1.Exception.internal(`logger ${key} already exists`));
        loggers.set(key, logger);
    };
    Logger.flush = async () => {
        for (const [key, logger] of loggers) {
            await logger.flush();
        }
    };
    Logger.log = (message, namespace = 'default', context = {}) => {
        for (const [key, logger] of loggers) {
            logger.log(message, namespace, context);
        }
    };
    Logger.createSegment = (traceId) => {
        const segments = [];
        for (const [key, logger] of loggers) {
            segments.push([key, logger.createSegment(traceId)]);
        }
        return new LoggerSegmentsWrapper(segments);
    };
    /**
     * @deprecated Please change to Logger.log()
     */
    function error(message, namespace = 'default') {
        Logger.log(message, namespace);
    }
    Logger.error = error;
    /**
     * @deprecated Please change to Logger.log()
     */
    function warn(message, namespace = 'default') {
        Logger.log(message, namespace);
    }
    Logger.warn = warn;
    function debug(message, namespace = 'airboat:default') {
        Debugger(namespace)(message);
    }
    Logger.debug = debug;
})(Logger = exports.Logger || (exports.Logger = {}));
//# sourceMappingURL=index.js.map